import * as dynamodb from "aws-cdk-lib/aws-dynamodb";
import * as events from "aws-cdk-lib/aws-events";
import * as iam from "aws-cdk-lib/aws-iam";
import * as lambda from "aws-cdk-lib/aws-lambda";
import { Construct } from "constructs";
import { LambdaBase, LambdaProps } from "../constructs/LambdaBase";
type TestResultsTablePropsBase = Omit<dynamodb.TableProps, "partitionKey" | "timeToLiveAttribute">;
/**
 * Configuration options for DynamoDB Table used to store outcome of test runs.
 */
export interface TestResultsTableProps extends TestResultsTablePropsBase {
    dataRetentionDays?: number;
}
/**
 * Configuration options for Lambda function used by {@link TestRunner}
 */
export type TestRunnerLambdaProps = Omit<LambdaProps, "code" | "handler" | "environment">;
/**
 * Configuration optinos for {@link TestRunner} CDK Construct
 */
export interface TestRunnerProps {
    /**
     * Folder path where test scripts are stored
     */
    specDir: string;
    /**
     * Give a friendly name to the Lambda function created by TestRunner
     */
    functionName?: string;
    /**
     * By default, TestRunner will construct an IAM role with policies need to execute. Optionally,
     * the role can be provided explicitly and TestRunner will not construct its own.
     */
    role?: iam.IRole;
    /**
     * CloudWatch Metrics namespace used by TestRunner
     */
    metricNamespace?: string;
    /**
     * Extra environment variables that can be given to TestRunner. These variables can then be
     * accessed from test code.
     */
    environment?: Record<string, string>;
    /**
     * {@link TestResultsTableProps} configuration properties for created DynamoDB Table
     */
    resultsTable?: TestResultsTableProps;
    /**
     * {@link TestRunnerLambdaProps} configuration properties for created Lambda Function
     */
    lambdaOptions?: TestRunnerLambdaProps;
    /**
     * Provide {@link events.Schedule} to activate TestRunner on a schedule.
     */
    schedule?: events.Schedule;
}
/**
 * TestRunner CDK construct.
 *
 * Create a suite of unit tests using the [Jasmine](https://jasmine.github.io/setup/nodejs.html)
 * unit testing framework. Then use the `TestRunner` construct to deploy them into an AWS Lambda
 * function.
 */
export declare class TestRunner extends Construct implements iam.IGrantable {
    readonly testResultTable: dynamodb.Table | undefined;
    readonly testRunnerLambda: LambdaBase;
    readonly functionUrl: lambda.FunctionUrl;
    private readonly builder;
    /**
     * IAM Role used for permissions while executing
     */
    get role(): iam.IRole;
    get grantPrincipal(): iam.IPrincipal;
    /**
     * Name of the Lambda Function created
     */
    get functionName(): string;
    /**
     * Constructs TestRunner CDK Construct
     *
     * @param scope - root {@link Construct} for TestRunner resources
     * @param id -
     * @param props - {@link TestRunnerProps}
     */
    constructor(scope: Construct, id: string, props: TestRunnerProps);
    private createTestResultsTable;
    private createSchedule;
}
export {};
